@@ -27,7 +27,7 @@ assay_facets: Facets = {
         ),
         "Data": FacetConfig(
             ["/nanostring/raw_data.csv", "/nanostring/normalized_data.csv"],
-            "tabulated data across all samples in a batch",
+            "Tabulated data across all samples in a batch",
         ),
     },
     "CyTOF": {
@@ -57,9 +57,9 @@ assay_facets: Facets = {
         ),
         "Combined Cell Counts": FacetConfig(
             [
-                "csv|cell counts compartment",
-                "csv|cell counts assignment",
-                "csv|cell counts profiling",
+                "/cytof_analysis/combined_cell_counts_compartment.csv",
+                "/cytof_analysis/combined_cell_counts_assignment.csv",
+                "/cytof_analysis/combined_cell_counts_profiling.csv",
             ],
             "Summary cell counts, combined across all samples in the trial",
         ),
@@ -255,10 +255,14 @@ assay_facets: Facets = {
                 "/tcr/replicate_/i2.fastq.gz",
             ]
         ),
-        "Misc.": FacetConfig(["/tcr/SampleSheet.csv" "/tcr/summary_info.csv"]),
+        "Misc.": FacetConfig(["/tcr/SampleSheet.csv" "/tcr_analysis/summary_info.csv"]),
         "Analysis Data": FacetConfig(
-            ["/tcr_analysis/tra_clone.csv", "/tcr_analysis/trb_clone.csv"],
-            "Data files from TCRseq analysis indicating TRA & TRB clones UMI counts",
+            [
+                "/tcr_analysis/tra_clone.csv",
+                "/tcr_analysis/trb_clone.csv",
+                "/tcr_analysis/report_trial.tar.gz",
+            ],
+            "Data files and Report from TCRseq analysis indicating TRA & TRB clones' UMI counts",
         ),
     },
     "ELISA": {"Data": FacetConfig(["/elisa/assay.xlsx"])},
@@ -278,22 +282,22 @@ clinical_facets: Facets = {
 }
 
 analysis_ready_facets = {
-    "Olink": FacetConfig(["npx|analysis_ready|csv"],),
+    "Olink": FacetConfig(["npx|analysis_ready|csv"]),
     "CyTOF": FacetConfig(
         [
-            "csv|cell counts compartment",
-            "csv|cell counts assignment",
-            "csv|cell counts profiling",
+            "/cytof_analysis/combined_cell_counts_compartment.csv",
+            "/cytof_analysis/combined_cell_counts_assignment.csv",
+            "/cytof_analysis/combined_cell_counts_profiling.csv",
         ],
         "Summary cell counts, combined across all samples in the trial",
     ),
-    "IHC": FacetConfig(["csv|ihc marker combined"],),
+    "IHC": FacetConfig(["csv|ihc marker combined"]),
     "Nanostring": FacetConfig(
         ["/nanostring/normalized_data.csv"],
-        "tabulated data across all samples in a batch",
+        "Tabulated data across all samples in a batch",
     ),
-    "RNA": FacetConfig(["/rna/analysis/salmon/quant.sf"],),
-    "WES": FacetConfig(["/wes/analysis/report.tar.gz"],),
+    "RNA": FacetConfig(["/rna/analysis/salmon/quant.sf"]),
+    "WES": FacetConfig(["/wes/analysis/report.tar.gz"]),
     "TCR": FacetConfig(
         ["/tcr_analysis/tra_clone.csv", "/tcr_analysis/trb_clone.csv"],
         "Data files from TCRseq analysis indicating TRA & TRB clones UMI counts",
